@@ -63,6 +63,7 @@ def parse_and_serialize(
 
 def _format_and_kws(fmt):
     """
+    ```python
     >>> _format_and_kws("fmt")
     ('fmt', {})
     >>> _format_and_kws("fmt:+a")
@@ -75,6 +76,8 @@ def _format_and_kws(fmt):
     ('fmt', {'c': 'd'})
     >>> _format_and_kws("fmt:a=b:c")
     ('fmt', {'a': 'b:c'})
+
+    ```
     """
     fmt, kws = fmt, {}
     if fmt and ":" in fmt:
